@@ -9,3 +9,8 @@ class TestKernelManagement(TestCase):
         self.assertIsInstance(KernelManagement.KernelManagementVersionString, bytes)
 
         self.assertIsInstance(KernelManagement.OSKernelManagementErrorDomain, str)
+
+
+class TestCallableMetadata(TestCase):
+    def test_callable_metadata_is_sane(self):
+        self.assertCallableMetadataIsSane(KernelManagement)
